pub struct FieldsReport {
pub source: SourceName,
pub fields: Vec<FieldReport>,
}Expand description
The plan and verified outcome of setting up every field a source’s configuration names.
Fields
source: SourceNameThe configured source name.
fields: Vec<FieldReport>Status, always, and Priority when the source sets priority_mapping.